poplar_isocc - Enforce ISO-3166-1 Country Code in Sage 300 — poplar_isocc 1.0.0 documentation

# poplar_isocc - Enforce ISO-3166-1 Country Code in Sage 300

This package enforces the use of ISO-3166-1 compliant country codes in any field in the Sage Desktop. It contains validation code as well as unit and acceptance tests.

- poplar_isocc
- Testing

`poplar_isocc` part of a general demonstration of how Python Packaging can be used with Orchid Extender. Best consumed with the accompanying presentation, Python Packaging for Extender - ISO Country Codes and a cold beer.

The code in this package is very simple, relying on the iso3166 package for reference data and performing only a simple validation. It demonstrates the key concepts in improving code reuse and distribution for Extender, including:

- leveraging the extools library for testing
- inclusion of unit and acceptance testing using ExTestCase
- how packaging can make installation, upgrade, and backport a breeze

This package, the Python Package Manager for Orchid Extender, and the extools library were created and are maintained by 2665093 Ontario Inc. Comments and quesions are always welcome, send an email.